summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorMickaël Rémond <mickael.remond@process-one.net>2007-12-24 12:58:05 +0000
committerMickaël Rémond <mickael.remond@process-one.net>2007-12-24 12:58:05 +0000
commitcd82cadd10f805fab562a3537c51a538c7636fa8 (patch)
tree68dfe96dc51e501cb6f7b6beebbe1c5e0c7bbd46 /src
parent* Fixed typo. (diff)
* applied copyright patch 2.
SVN Revision: 1112
Diffstat (limited to 'src')
-rw-r--r--src/mod_echo.erl27
-rw-r--r--src/mod_last.erl26
-rw-r--r--src/mod_last_odbc.erl26
-rw-r--r--src/mod_offline.erl19
-rw-r--r--src/mod_offline_odbc.erl19
-rw-r--r--src/mod_privacy.erl26
-rw-r--r--src/mod_privacy_odbc.erl26
-rw-r--r--src/mod_private.erl28
-rw-r--r--src/mod_private_odbc.erl26
-rw-r--r--src/mod_register.erl26
-rw-r--r--src/mod_roster.erl25
-rw-r--r--src/mod_roster_odbc.erl25
-rw-r--r--src/mod_service_log.erl26
-rw-r--r--src/mod_shared_roster.erl26
-rw-r--r--src/mod_stats.erl28
-rw-r--r--src/mod_time.erl26
-rw-r--r--src/mod_vcard.erl27
-rw-r--r--src/mod_vcard_ldap.erl25
-rw-r--r--src/mod_vcard_odbc.erl25
-rw-r--r--src/mod_version.erl25
-rw-r--r--src/randoms.erl28
-rw-r--r--src/sha.erl26
-rw-r--r--src/shaper.erl26
-rw-r--r--src/translate.erl28
-rw-r--r--src/xml.erl26
-rw-r--r--src/xml_stream.erl26
26 files changed, 572 insertions, 95 deletions
diff --git a/src/mod_echo.erl b/src/mod_echo.erl
index 05067730..de51f7b6 100644
--- a/src/mod_echo.erl
+++ b/src/mod_echo.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_echo.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 15 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Simple ejabberd module.
+%%% Created : 15 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_echo).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
-behaviour(gen_mod).
diff --git a/src/mod_offline.erl b/src/mod_offline.erl
index b3598926..dbce7513 100644
--- a/src/mod_offline.erl
+++ b/src/mod_offline.erl
@@ -3,6 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Store and manage offline messages in Mnesia database.
%%% Created : 5 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_offline).
diff --git a/src/mod_offline_odbc.erl b/src/mod_offline_odbc.erl
index f7097d73..abcbcacf 100644
--- a/src/mod_offline_odbc.erl
+++ b/src/mod_offline_odbc.erl
@@ -3,6 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Store and manage offline messages in relational database.
%%% Created : 5 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_offline_odbc).
diff --git a/src/mod_private.erl b/src/mod_private.erl
index 97ca08ad..e4a5d451 100644
--- a/src/mod_private.erl
+++ b/src/mod_private.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_private.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 16 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Support for private storage.
+%%% Created : 16 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_private).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
diff --git a/src/mod_stats.erl b/src/mod_stats.erl
index 091bff18..7244c202 100644
--- a/src/mod_stats.erl
+++ b/src/mod_stats.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_stats.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 11 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Basic statistics.
+%%% Created : 11 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_stats).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
diff --git a/src/mod_vcard.erl b/src/mod_vcard.erl
index 3cdd52b8..fedc8f40 100644
--- a/src/mod_vcard.erl
+++ b/src/mod_vcard.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_vcard.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Vcard management in Mnesia
+%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_vcard).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
diff --git a/src/randoms.erl b/src/randoms.erl
index c6d5e87d..eaa7875a 100644
--- a/src/randoms.erl
+++ b/src/randoms.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : randoms.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 13 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Random generation number wrapper
+%%% Created : 13 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(randoms).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([get_string/0]).
diff --git a/src/translate.erl b/src/translate.erl
index a6cc8c14..bb069dbc 100644
--- a/src/translate.erl
+++ b/src/translate.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : translate.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 6 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Localization helper
+%%% Created : 6 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(translate).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0,
load_dir/1,
diff --git a/src/mod_last.erl b/src/mod_last.erl
index 1f0d1edc..1af31473 100644
--- a/src/mod_last.erl
+++ b/src/mod_last.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_last.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : jabber:iq:last support (JEP-0012)
-%%% Created : 24 Oct 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 24 Oct 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_last).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_last.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : jabber:iq:last support (JEP-0012)
diff --git a/src/mod_last_odbc.erl b/src/mod_last_odbc.erl
index 4954451f..efd28d7c 100644
--- a/src/mod_last_odbc.erl
+++ b/src/mod_last_odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_last_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : jabber:iq:last support (JEP-0012)
-%%% Created : 24 Oct 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 24 Oct 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_last_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_last_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : jabber:iq:last support (JEP-0012)
diff --git a/src/mod_privacy.erl b/src/mod_privacy.erl
index 50aa97ae..ea189036 100644
--- a/src/mod_privacy.erl
+++ b/src/mod_privacy.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_privacy.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : jabber:iq:privacy support
-%%% Created : 21 Jul 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 21 Jul 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_privacy).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_privacy.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : jabber:iq:privacy support
diff --git a/src/mod_privacy_odbc.erl b/src/mod_privacy_odbc.erl
index 7f13cdac..84099747 100644
--- a/src/mod_privacy_odbc.erl
+++ b/src/mod_privacy_odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_privacy_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : jabber:iq:privacy support
-%%% Created : 5 Oct 2006 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 5 Oct 2006 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_privacy_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_privacy_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : jabber:iq:privacy support
diff --git a/src/mod_private_odbc.erl b/src/mod_private_odbc.erl
index 0bb31598..51b55934 100644
--- a/src/mod_private_odbc.erl
+++ b/src/mod_private_odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_private_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Private storage support
-%%% Created : 5 Oct 2006 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 5 Oct 2006 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_private_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_private_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Private storage support
diff --git a/src/mod_register.erl b/src/mod_register.erl
index 242fd744..c56d6f47 100644
--- a/src/mod_register.erl
+++ b/src/mod_register.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_register.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Inband registration support
-%%% Created : 8 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 8 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_register).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_register.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Inband registration support
diff --git a/src/mod_roster.erl b/src/mod_roster.erl
index 4fdbce1f..3326e075 100644
--- a/src/mod_roster.erl
+++ b/src/mod_roster.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_roster.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Roster management
-%%% Created : 11 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 11 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_roster).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_roster.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Roster management
diff --git a/src/mod_roster_odbc.erl b/src/mod_roster_odbc.erl
index 27cab420..b4b76300 100644
--- a/src/mod_roster_odbc.erl
+++ b/src/mod_roster_odbc.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_roster_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Roster management
-%%% Created : 15 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 15 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_roster_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_roster_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Roster management
diff --git a/src/mod_service_log.erl b/src/mod_service_log.erl
index aa664015..5c070b09 100644
--- a/src/mod_service_log.erl
+++ b/src/mod_service_log.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_service_log.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Copy user messages to logger service
-%%% Created : 24 Aug 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 24 Aug 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_service_log).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_service_log.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Copy user messages to logger service
diff --git a/src/mod_shared_roster.erl b/src/mod_shared_roster.erl
index 6703810b..3741a1bf 100644
--- a/src/mod_shared_roster.erl
+++ b/src/mod_shared_roster.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_shared_roster.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Shared roster management
-%%% Created : 5 Mar 2005 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 5 Mar 2005 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_shared_roster).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_shared_roster.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Shared roster management
diff --git a/src/mod_time.erl b/src/mod_time.erl
index 6746f8e5..4ec85cd7 100644
--- a/src/mod_time.erl
+++ b/src/mod_time.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_time.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose :
-%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_time).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_time.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose :
diff --git a/src/mod_vcard_ldap.erl b/src/mod_vcard_ldap.erl
index e7b751ee..65696169 100644
--- a/src/mod_vcard_ldap.erl
+++ b/src/mod_vcard_ldap.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_vcard_ldap.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Support for VCards from LDAP storage.
-%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_vcard_ldap).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
-behaviour(gen_mod).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_vcard_ldap.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Support for VCards from LDAP storage.
diff --git a/src/mod_vcard_odbc.erl b/src/mod_vcard_odbc.erl
index d5fc9eaa..86c185fe 100644
--- a/src/mod_vcard_odbc.erl
+++ b/src/mod_vcard_odbc.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_vcard.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : vCard support via ODBC
-%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 2 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_vcard_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_vcard.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : vCard support via ODBC
diff --git a/src/mod_version.erl b/src/mod_version.erl
index ec71a8ee..87398f72 100644
--- a/src/mod_version.erl
+++ b/src/mod_version.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_version.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : XEP-0092: Software Version
-%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_version).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_version.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : XEP-0092: Software Version
diff --git a/src/sha.erl b/src/sha.erl
index 322ca2e1..2cbd44fd 100644
--- a/src/sha.erl
+++ b/src/sha.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : sha.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose :
-%%% Created : 20 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 20 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(sha).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0, sha/1]).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : sha.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose :
diff --git a/src/shaper.erl b/src/shaper.erl
index 88e9a31b..bbbf1be7 100644
--- a/src/shaper.erl
+++ b/src/shaper.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : shaper.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Functions to control connections traffic
-%%% Created : 9 Feb 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 9 Feb 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(shaper).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([new/1, new1/1, update/2]).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : shaper.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Functions to control connections traffic
diff --git a/src/xml.erl b/src/xml.erl
index d2a6d8af..5802f290 100644
--- a/src/xml.erl
+++ b/src/xml.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : xml.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : XML utils
-%%% Created : 20 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 20 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(xml).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([element_to_string/1,
crypt/1, make_text_node/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : xml.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : XML utils
diff --git a/src/xml_stream.erl b/src/xml_stream.erl
index cefae116..8fa47421 100644
--- a/src/xml_stream.erl
+++ b/src/xml_stream.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : xml_stream.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Parse XML streams
-%%% Created : 17 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 17 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(xml_stream).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([new/1,
new/2,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : xml_stream.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Parse XML streams